# Query the Fast Radio Burst Catalogue in Python
**David Gardenier** | ASTRON

## Installation

```sh
pip3 install frbcat
```

## Usage
Get a Pandas DataFrame using
```python
from frbcat import Frbcat
df = Frbcat().df
```

## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request


## License

Distributed under the MIT License. See `LICENSE` for more information.


## Contact
Author: David Gardenier - gardenier@astron.nl

Project Link: [https://github.com/davidgardenier/frbcat](https://github.com/davidgardenier/frbcat)
